@@ -2,7 +2,7 @@ from django.urls import path
 from rest_framework.routers import DefaultRouter
 
 from blog.views import ( EntryViewSet, ListUser, CommentViewSet, SyncConfig, TagViewSet, ViewViewSet,
-                        InteractionViewSet, VisitorProfileViewSet )
+                        InteractionViewSet, VisitorProfileViewSet, EntriesFeed )
 
 router = DefaultRouter()
 
@@ -16,4 +16,5 @@ router.register(r'visitor_profiles', VisitorProfileViewSet, basename='visitor_pr
 urlpatterns = [
     path('me/', ListUser.as_view()),
     path('sync_config/', SyncConfig.as_view()),
+    path('rss/', EntriesFeed()),
 ] + router.urls
